==> haskell-random-source-0.3.0.11-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-source.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 random-source
version:              0.3.0.11
visibility:           public
id:                   random-source-0.3.0.11-FGzIdKM1Egn3Tid6Y03A2
key:                  random-source-0.3.0.11-FGzIdKM1Egn3Tid6Y03A2
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/random-fu
synopsis:             Generic basis for random number generators
description:
    Random number generation based on entropy sources
    able to produce a small but well-defined set of
    primitive variates.  Also includes facilities for
    \"completing\" partial implementations, making it
    easy to define new entropy sources in a way that
    is naturally forward-compatible.

category:             Math
abi:                  38d5138854e5bf40d3d9c87b949aff55
exposed:              True
exposed-modules:
    Data.Random.Internal.Source Data.Random.Internal.Words
    Data.Random.Source Data.Random.Source.DevRandom
    Data.Random.Source.IO Data.Random.Source.MWC
    Data.Random.Source.PureMT Data.Random.Source.Std
    Data.Random.Source.StdGen

hidden-modules:
    Data.Random.Source.Internal.Prim Data.Random.Source.Internal.TH

import-dirs:          /usr/lib/ghc-9.0.1/site-local/random-source-0.3.0.11
library-dirs:         /usr/lib/ghc-9.0.1/site-local/random-source-0.3.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/random-source-0.3.0.11
hs-libraries:         HSrandom-source-0.3.0.11-FGzIdKM1Egn3Tid6Y03A2
depends:
    base-4.15.0.0 flexible-defaults-0.0.3-8DK9Nz3SKndMHqfjIfspm
    mersenne-random-pure64-0.2.2.0-156p0Adfmr3HQyeNj6b9ED mtl-2.2.2
    mwc-random-0.15.0.1-5GAsPmEoCTVAmzLDfBigIH
    primitive-0.7.1.0-KvjkSKnzuhtan9loX8sTh
    random-1.2.0-LPOc7Wg7qroFr0u40myEtC
    stateref-0.3-Jp7AuxKnQwJEjEJAudyXqA
    syb-0.7.2.1-J5q3iPBtnlLDQl43DMfXCR template-haskell-2.17.0.0
    th-extras-0.0.0.4-3Dv23EkeJ8G2nXH3epGKpd

haddock-interfaces:
    /usr/share/doc/haskell-random-source/html/random-source.haddock

haddock-html:         /usr/share/doc/haskell-random-source/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-random-source-0.3.0.11-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-source.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 random-source
version:              0.3.0.11
visibility:           public
id:                   random-source-0.3.0.11-J62DZpXrDR3IJyTM1fV68Y
key:                  random-source-0.3.0.11-J62DZpXrDR3IJyTM1fV68Y
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/random-fu
synopsis:             Generic basis for random number generators
description:
    Random number generation based on entropy sources
    able to produce a small but well-defined set of
    primitive variates.  Also includes facilities for
    \"completing\" partial implementations, making it
    easy to define new entropy sources in a way that
    is naturally forward-compatible.

category:             Math
abi:                  e249d545f0f83c2d3158d6026ac53ff5
exposed:              True
exposed-modules:
    Data.Random.Internal.Source Data.Random.Internal.Words
    Data.Random.Source Data.Random.Source.DevRandom
    Data.Random.Source.IO Data.Random.Source.MWC
    Data.Random.Source.PureMT Data.Random.Source.Std
    Data.Random.Source.StdGen

hidden-modules:
    Data.Random.Source.Internal.Prim Data.Random.Source.Internal.TH

import-dirs:          /usr/lib/ghc-9.0.1/site-local/random-source-0.3.0.11
library-dirs:         /usr/lib/ghc-9.0.1/site-local/random-source-0.3.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/random-source-0.3.0.11
hs-libraries:         HSrandom-source-0.3.0.11-J62DZpXrDR3IJyTM1fV68Y
depends:
    base-4.15.0.0 flexible-defaults-0.0.3-GuwjjOBYK82CxoqzMvOQem
    mersenne-random-pure64-0.2.2.0-IeNKArIkUQeJPlUSzECLO4 mtl-2.2.2
    mwc-random-0.15.0.1-9E3nK75awP1FaxayB15Bu8
    primitive-0.7.1.0-FzMFSpjFTSY7YtlPPz98XL
    random-1.2.0-FfulI1BwpsjGO0LPW59p9g
    stateref-0.3-Jp7AuxKnQwJEjEJAudyXqA
    syb-0.7.2.1-8cP5Vs8FXNOBPC9jzxibP7 template-haskell-2.17.0.0
    th-extras-0.0.0.4-KZUrBrZyhYwHPqFFIoHLtD

haddock-interfaces:
    /usr/share/doc/haskell-random-source/html/random-source.haddock

haddock-html:         /usr/share/doc/haskell-random-source/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
